function [t,x1]=dewpt2(p,y)
% dewpt2	- Give the dewpoint for a BINARY mixture (See also dewpt)
% function [t,x1]=dewpt2(p,y)
% Argument List:
% Argument    Gives
%    p       pressure in kPa
%    y      mol fraction of 1st component in the vapor.
% Returns     Giving
%    t       Dew point temp. in Tdeg.
%    x1     liquid mol fraction of 1st component in equil.
%            with the vapor at the dew point.
% Ex: start301a in Unix: give the names: benzene, toluene
%   >> start301b 
%     [t,x1]=dewpt2(101,.3)
%     t will have the dew point and x1 the liquid mol frac.
ts=teql(p);
cs=[p,y,1-y];
t=ssec2(ts,'1-sum(c(2:3)./kval(x,c(1)))',cs);
ks=kval(t,p);
x1=y/ks(1);
